Learn R Programming

fame (version 2.7)

isFameScalar: Check for (Fame or Numeric) Scalar or Time Index Series

Description

isFameScalar checks whether or not its argument could be a 'scalar' in FAME parlance, i.e., if it is an atomic object of length one and not a time series or time indexed series. ti objects of length one are what FAME calls a 'date', other scalars are strings, numbers, and logicals of length one.

Usage

isFameScalar(x)

Arguments

x
object to be checked.

Value

  • TRUE or FALSE.

Examples

Run this code
isFameScalar("this is a scalar, since it has length one")
isFameScalar(c("returns FALSE", "since it has length two"))
isFameScalar(today())

Run the code above in your browser using DataLab